package com.gxzc.zen.web.sys.controller

import com.baomidou.kisso.SSOHelper
import com.baomidou.kisso.security.token.SSOToken
import com.gxzc.zen.api.sys.service.ISysUserRoleService
import com.gxzc.zen.api.sys.service.ISysUserService
import com.gxzc.zen.common.base.BaseController
import com.gxzc.zen.common.dto.ResponseDto
import com.gxzc.zen.common.exception.ZenException
import com.gxzc.zen.common.exception.ZenExceptionEnum
import org.slf4j.LoggerFactory
import org.springframework.beans.factory.annotation.Autowired
import org.springframework.http.ResponseEntity
import org.springframework.web.bind.annotation.GetMapping
import org.springframework.web.bind.annotation.RequestMapping
import org.springframework.web.bind.annotation.RestController

/**
 * 用户相关控制器
 * @author NorthLan
 * @date 2018/3/2
 * @url https://noahlan.com
 */
@RestController
@RequestMapping("user")
class UserController : BaseController() {
    companion object {
        private val logger = LoggerFactory.getLogger(UserController::class.java)
    }

    @Autowired
    private lateinit var userRoleService: ISysUserRoleService

    @Autowired
    private lateinit var userService: ISysUserService


    @GetMapping("/userInfo")
    fun userInfo(): ResponseEntity<*> {
        val token: SSOToken = SSOHelper.getSSOToken(getRequest())
                ?: throw ZenException(ZenExceptionEnum.AUTH_NO_LOGIN) // 未登录直接跳出
        val userRoleList = userRoleService.getUserRoleListByUserId(token.id.toLong())
        val userInfo = userService.getUserByIdCacheable(token.id.toLong())

        return ResponseEntity.ok(ResponseDto().also {
            it.data["info"] = mutableMapOf(
                    Pair("account", userInfo.account),
                    Pair("username", userInfo.username),
                    Pair("id", userInfo.id))
            it.data["roles"] = userRoleList
        })
    }
}